Storage
-------

.. automodule:: qarnot.storage
    :members:
    :show-inheritance:
    :special-members:
    :exclude-members: __dict__,__weakref__,__getitem__,__setitem__,__delitem__,__contains__,__iter__,__eq__,__ne__,__hash__
